import { Injectable } from '@angular/core';
import { ActivatedRouteSnapshot, Router, RouterStateSnapshot, UrlTree } from '@angular/router';
import { KeycloakAuthGuard } from 'keycloak-angular';
import { AuthProviderService } from '../services/keycloak/auth-provider.service';

@Injectable({
  providedIn: 'root'
})
export class AuthGuard extends KeycloakAuthGuard {

  constructor(
    protected router: Router,
    protected readonly authProviderService: AuthProviderService) {
    super(router, authProviderService.getProvider());
  }
  
  /**
   * Permet de vérifier l'accès/l'authification de l'utilisateur
   * 
   * @param route 
   * @param state 
   * @returns Promise
   */
  async isAccessAllowed(route: ActivatedRouteSnapshot, state: RouterStateSnapshot): Promise<boolean | UrlTree> {
    if (!this.authenticated) {
      console.log('Not authenticated. Redirect to login page ...');
      this.router.navigateByUrl('/login');
      // await this.authProviderService.getProvider().login({
      //   redirectUri: window.location.origin + state.url,
      // });
    }
    
    return this.authenticated;
  }
  
}
