import { Injectable } from '@angular/core';
import { Platform } from '@ionic/angular';
import { KeycloakService } from 'keycloak-angular';
import { environment } from 'src/environments/environment';
import { KEYCLOAK_CONFIG_LOCAL_URL, KEYCLOAK_CONFIG_URL, LOGIN_REQUIRED, SILENT_CHECK_SSO } from 'src/shared/constants';

@Injectable({
  providedIn: 'root'
})
export class AuthProviderService {
  private keycloakConfigFile: any;

  constructor(private keycloakService: KeycloakService,
    private platform: Platform) { 
   this.keycloakConfigFile = environment.production ? KEYCLOAK_CONFIG_URL
     : KEYCLOAK_CONFIG_LOCAL_URL;
  }

  /**
   * Méthode d'initialisation Keycloak
   * utilise la méthode par défaut de la lib keycloak-js (keycloak-angular)
   * 
   * @returns Promise
   */
  init(): Promise<boolean> {
    console.log(this.keycloakConfigFile);
    return this.keycloakService.init({
      config: this.keycloakConfigFile,
      initOptions: {
        adapter: 'cordova',
        onLoad: 'check-sso',
        checkLoginIframe: true,
        enableLogging: true,
        // redirectUri: 'mynatan-ionic-keycloak://app'
        // silentCheckSsoFallback: false,
        silentCheckSsoRedirectUri: SILENT_CHECK_SSO
      },
      // bearerExcludedUrls: ['test$'],
      enableBearerInterceptor: false
    });
  }

  /**
   * Getter du service keycloak
   * 
   * @returns KeycloakService
   */
  getProvider(): KeycloakService {
    return this.keycloakService;
  }

  /**
   * Recupere le token keycloak
   * 
   * @returns Promise
   */
  getToken(): Promise<any> {
    return new Promise((resolve, reject) => {
      this.keycloakService.getToken()
        .then(token => {
          // this.storageService.store('authenticationToken', token);
          resolve(token);
        })
        .catch(reason => {
          console.log('Failed to get token', reason);
          reject(reason);
        });
    });
  }
  
  /**
   * Méthode de deconnexion de keycloak
   * 
   * @returns 
   */
  logout(): Promise<any>{
    return this.keycloakService.logout();
  }
}
